.. _isomorphism:
.. _networkx.algorithms.isomorphism.isomorph:

***********
Isomorphism
***********

.. automodule:: networkx.algorithms.isomorphism
.. autosummary::
   :toctree: generated/

   is_isomorphic
   could_be_isomorphic
   fast_could_be_isomorphic
   faster_could_be_isomorphic

VF2++
-----
.. automodule:: networkx.algorithms.isomorphism.vf2pp
.. autosummary::
   :toctree: generated/

   vf2pp_is_isomorphic
   vf2pp_all_isomorphisms
   vf2pp_isomorphism

Tree Isomorphism
-----------------
.. automodule:: networkx.algorithms.isomorphism.tree_isomorphism
.. autosummary::
   :toctree: generated/

    rooted_tree_isomorphism
    tree_isomorphism


Advanced Interfaces
-------------------
.. toctree::
   :maxdepth: 2

   isomorphism.vf2
   isomorphism.ismags

